clean_database: Helper function to drop all tables from a database

View source: R/helper_database.R

clean_databaseR Documentation

Helper function to drop all tables from a database

Description

Helper function to drop all tables from a database

Usage

clean_database(con)

Arguments

con

DBI connection

Value

invisible, a lit with result from DBI


repana documentation built on May 29, 2024, 10:36 a.m.