| get_pool | R Documentation |
This function get a pool connection to a database reading the parameters from a
config.yml file using the get function.
See the vignette for details.
get_pool(configname = "defaultdb", file = "config.yml")
configname |
a string with the name of the value |
file |
name of the configuration to read from. |
a dbPool connection object
John J. Aponte
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.