targets_structure: Create configuration to use targets

View source: R/repana_targets.R

targets_structureR Documentation

Create configuration to use targets

Description

Create of they do not exist the following directories

  • R

  • dat

  • out

Usage

targets_structure()

Details

If does not exists, create a simplify version of the ⁠_targets.R⁠ script, modify the .gitignore. Also add a config.yml and a ⁠_template.txt⁠ files.

Examples

 ## Not run: 
targets_structure()

## End(Not run)


johnaponte/repana documentation built on Feb. 24, 2025, 3:35 a.m.