View source: R/repana_targets.R
| targets_structure | R Documentation |
Create of they do not exist the following directories
R
dat
out
targets_structure()
If does not exists, create a simplify version of the _targets.R script,
modify the .gitignore. Also add a config.yml and a _template.txt
files.
## Not run:
targets_structure()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.